import { useCallback, useRef } from 'react';
import useUpdate from "./useUpdate";
/**
 * 用于实现受控与非受控特性
 * @param props
 * @param controlKeys
 * @returns
 */
export default function useControlValue(props) {
  var controlKeys = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
    valueKey: 'value',
    defaultValueKey: 'defaultValue',
    eventKey: 'onChange'
  };
  var valueKey = controlKeys.valueKey,
    defaultKey = controlKeys.defaultValueKey,
    eventKey = controlKeys.eventKey;
  var value = props[valueKey];
  var defaultValue = props[defaultKey];
  var onChange = props[eventKey];
  var update = useUpdate();
  var stateRef = useRef(value !== undefined ? value : defaultValue);
  if (value !== undefined) {
    stateRef.current = value;
  }
  var setState = useCallback(function (v) {
    var forceTrigger = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
    // `forceTrigger` means trigger `onChange` even if `v` is the same as `stateRef.current`
    var nextValue = typeof v === 'function' ? v(stateRef.current) : v;
    if (!forceTrigger && nextValue === stateRef.current) return;
    stateRef.current = nextValue;
    update();
    for (var _len = arguments.length, args = new Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
      args[_key - 2] = arguments[_key];
    }
    return onChange === null || onChange === void 0 ? void 0 : onChange.apply(void 0, [nextValue].concat(args));
  }, [onChange, update]);
  return [stateRef.current, setState];
}